@@ -33,7 +33,7 @@ gsize session_number = 0;
 gboolean had_error, paused, first_load_groups = TRUE, dryrunning = FALSE, must_scroll = FALSE, is_set = FALSE;
 gchar **groups = NULL, **argv, *error_list = NULL, *watch_oldfile = NULL;
 GtkWidget *rsync_window = NULL;
-gboolean config_output = FALSE, config_remember = TRUE, config_errorlist = FALSE, config_log = FALSE, config_fastscroll = TRUE;
+gboolean config_output = FALSE, config_remember = TRUE, config_errorlist = FALSE, config_log = FALSE, config_log_overwrite = FALSE, config_fastscroll = TRUE;
 #ifndef MAEMO
 gboolean config_switchbutton = FALSE, config_trayicon = FALSE;
 #endif
@@ -163,6 +163,7 @@ void load_settings(gchar* session, gchar *filename) {
 		ini_get_boolean(settings_file, "remember", &config_remember);
 		ini_get_boolean(settings_file, "errorlist", &config_errorlist);
 		ini_get_boolean(settings_file, "logging", &config_log);
+		ini_get_boolean(settings_file, "logging_overwrite", &config_log_overwrite);
 		ini_get_boolean(settings_file, "fastscroll", &config_fastscroll);
 #ifndef MAEMO
 		ini_get_boolean(settings_file, "switchbutton", &config_switchbutton);
@@ -289,12 +290,13 @@ void save_settings(gchar *session, gchar *filename) {
 		g_key_file_set_boolean(settings_file, CONFIG_GROUP, "remember", config_remember);
 		g_key_file_set_boolean(settings_file, CONFIG_GROUP, "errorlist", config_errorlist);
 		g_key_file_set_boolean(settings_file, CONFIG_GROUP, "logging", config_log);
+		g_key_file_set_boolean(settings_file, CONFIG_GROUP, "logging_overwrite", config_log_overwrite);
 		g_key_file_set_boolean(settings_file, CONFIG_GROUP, "fastscroll", config_fastscroll);
 #ifndef MAEMO
 		g_key_file_set_boolean(settings_file, CONFIG_GROUP, "switchbutton", config_switchbutton);
 		g_key_file_set_boolean(settings_file, CONFIG_GROUP, "trayicon", config_trayicon);
 #endif
-		if (session_last != -1) g_key_file_set_string(settings_file, CONFIG_GROUP, "last_session", groups[session_last]);
+		if (session_last != -1 && config_remember) g_key_file_set_string(settings_file, CONFIG_GROUP, "last_session", groups[session_last]);
 
 		// window position and size
 		g_key_file_set_integer(settings_file, CONFIG_GROUP, "root_x", root_x);
@@ -687,7 +689,7 @@ void on_play_clicked(GtkButton *button, gpointer user_data) {
 
 	if (config_log) {
 		gtmp = g_strconcat(grsync_dir, "/", groups[session_last], ".log", NULL);
-		log_file = fopen(gtmp, "a");
+		log_file = fopen(gtmp, (config_log_overwrite ? "w" : "a"));
 		g_free(gtmp);
 	}
 
@@ -1104,10 +1106,11 @@ void on_rsync_show(GtkWidget *widget, gpointer user_data) {
 		comm_str = (gchar*) gtk_entry_get_text((GtkEntry*) gtk_builder_get_object(builder, "entry_com_before"));
 		if (!g_spawn_command_line_sync(comm_str, &comm_out, &comm_err, &err, NULL) || err) {
 			comm_out = g_strconcat("", NULL);
-			comm_err = g_strconcat("Error launching command!\n", NULL);
+			comm_err = g_strconcat("Error launching command!", NULL);
+			gtk_label_set_text((GtkLabel*) gtk_builder_get_object(builder, "label_file"), comm_err);
 			if (get_checkbox("check_com_halt")) halt = TRUE;
 		}
-		comm_before = g_strconcat(_("** Launching BEFORE command:\n"), comm_str, "\n", comm_out, comm_err, "\n", NULL);
+		comm_before = g_strconcat(_("** Launching BEFORE command:\n"), comm_str, "\n", comm_out, comm_err, "\n\n", NULL);
 		g_free(comm_out);
 		g_free(comm_err);
 	} else {
@@ -1385,6 +1388,7 @@ void on_preferences1_activate(GtkMenuItem *menuitem, gpointer user_data) {
 	set_checkbox("check_remember", config_remember);
 	set_checkbox("check_errorlist", config_errorlist);
 	set_checkbox("check_log", config_log);
+	set_checkbox("check_log_overwrite", config_log_overwrite);
 	set_checkbox("check_fastscroll", config_fastscroll);
 #ifndef MAEMO
 	set_checkbox("check_switchbutton", config_switchbutton);
@@ -1398,6 +1402,7 @@ void on_preferences1_activate(GtkMenuItem *menuitem, gpointer user_data) {
 		config_remember = get_checkbox("check_remember");
 		config_errorlist = get_checkbox("check_errorlist");
 		config_log = get_checkbox("check_log");
+		config_log_overwrite = get_checkbox("check_log_overwrite");
 		config_fastscroll = get_checkbox("check_fastscroll");
 #ifndef MAEMO
 		config_switchbutton = get_checkbox("check_switchbutton");
